@@ -1,8 +1,10 @@
-package Pod::ProjectDocs::Config 0.45;
+package Pod::ProjectDocs::Config;
 
 use strict;
 use warnings;
 
+our $VERSION = '0.48'; # VERSION
+
 use base qw/Class::Accessor::Fast/;
 
 use Readonly;
@@ -10,7 +12,6 @@ use Readonly;
 __PACKAGE__->mk_accessors(qw/
     title
     desc
-    charset
     verbose
     index
     outroot
@@ -22,13 +23,12 @@ __PACKAGE__->mk_accessors(qw/
 
 Readonly my $DEFAULT_TITLE   => qq/MyProject's Libraries/;
 Readonly my $DEFAULT_DESC    => qq/manuals and libraries/;
-Readonly my $DEFAULT_CHARSET => qq/UTF-8/;
 Readonly my $DEFAULT_LANG    => qq/en/;
 
 sub new {
-    my $class = shift;
+    my ($class, @args) = @_;
     my $self  = bless { }, $class;
-    $self->_init(@_);
+    $self->_init(@args);
     return $self;
 }
 
@@ -36,7 +36,6 @@ sub _init {
     my($self, %args) = @_;
     $self->title   ( $args{title}   || $DEFAULT_TITLE   );
     $self->desc    ( $args{desc}    || $DEFAULT_DESC    );
-    $self->charset ( $args{charset} || $DEFAULT_CHARSET );
     $self->lang    ( $args{lang}    || $DEFAULT_LANG    );
     $self->verbose ( $args{verbose}                     );
     $self->index   ( $args{index}                       );
@@ -44,6 +43,7 @@ sub _init {
     $self->libroot ( $args{libroot}                     );
     $self->forcegen( $args{forcegen}                    );
     $self->except  ( $args{except}                      );
+    return;
 }
 
 1;
