@@ -1,16 +1,18 @@
-package Pod::ProjectDocs::Template 0.45;
+package Pod::ProjectDocs::Template;
 
 use strict;
 use warnings;
 
+our $VERSION = '0.48'; # VERSION
+
 use Template;
 use File::Basename;
 use File::Spec;
 
 sub new {
-    my $class = shift;
+    my ($class, @args) = @_;
     my $self  = bless { }, $class;
-    $self->_init(@_);
+    $self->_init(@args);
     return $self;
 }
 
@@ -33,6 +35,7 @@ sub _init {
             }
         },
     } );
+    return;
 }
 
 sub process {
@@ -48,6 +51,7 @@ sub _croak {
     my($self, $msg) = @_;
     require Carp;
     Carp::croak($msg);
+    return;
 }
 
 1;
